#    Copyright 2009 Shelby M. Tucker
#        Email:     shelby.tucker@gmail.com
#
#    This file is part of Teletory Maker.
#
#    Teletory Maker is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Teletory Maker is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.#
#
#    You should have received a copy of the GNU General Public License
#    along with Teletory Maker.  If not, see <http://www.gnu.org/licenses/>.

from reportlab.pdfgen import canvas
from reportlab.lib.pagesizes import letter
from reportlab.lib.styles import getSampleStyleSheet
from reportlab.platypus import *
from reportlab.lib import colors

#Check if it's a business listing and return something fancy.
def CheckForBusiness(type):
    if type == 'work':
        return 'Business'
    else:
        return None #ReportLab uses a None object to fill a blank

def ExportPDF(data, file, config):
    elements = []
    styles = getSampleStyleSheet()
    doc = SimpleDocTemplate(file)
    
    #The header...
    elements.append(Paragraph(config.header,styles['Title']))
    
    #Build a list containing lists of the data for our listings.
    #    Needed to pass to PLATYPUS for table generation.
    tableData = []
    tableData.append(['Address', 'Name', 'Phone Number', ' Notes'])
    for listing in data:
            tableData.append([listing['full_address'], listing['name'],
                    listing['phone_num'], CheckForBusiness(listing['type'])])
            
    #Because I'm lazy... =(
    lb = lambda: config.labelBorder
    mb = lambda: config.mainBorder
    
    # First the top row, with all the text centered and in Times-Bold,
    # and one line above, one line below.
    ts = [('ALIGN', (1,1), (-1,-1), 'LEFT'),
          #Start with the labels...
          ('LINEBEFORE', (0,0), (-1,0), lb(), colors.black),
          ('LINEAFTER', (-1,0), (-1,0), lb(), colors.black),
          ('LINEABOVE', (0,0), (-1,0), lb(), colors.black),
          ('LINEBELOW', (0,0), (-1,0), lb(), colors.black),
          ('FONT', (0,0), (-1,0), 'Times-Bold'),
          ('FONTSIZE', (0,0), (-1,0), config.labelTextSize),
          #Now for the listings...
          ('LINEBEFORE', (0,1), (-1,-1), mb(), colors.black),
          ('LINEAFTER', (-1,1), (-1,-1), mb(), colors.black),
          ('LINEBELOW', (0,1), (-1,-1), mb(), colors.black),
          ('FONTSIZE', (0,1), (-1,-1), config.mainTextSize)]

    table = Table(tableData, style=ts, colWidths=[None, None, None, 200])
    elements.append(table)

    doc.build(elements)
